@@ -122,7 +122,7 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 
 	builder = CE_PAGE (self)->builder;
 
-	s_con = NM_SETTING_CONNECTION (nm_connection_get_setting (connection, NM_TYPE_SETTING_CONNECTION));
+	s_con = nm_connection_get_setting_connection (connection);
 	g_assert (s_con);
 	connection_type = nm_setting_connection_get_connection_type (s_con);
 	g_assert (connection_type);
@@ -980,7 +980,7 @@ ce_page_ip4_new (NMConnection *connection,
 	                                 "IP4Page",
 	                                 _("IPv4 Settings")));
 	if (!self) {
-		g_set_error_literal (error, 0, 0, _("Could not load IPv4 user interface."));
+		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not load IPv4 user interface."));
 		return NULL;
 	}
 
@@ -989,11 +989,11 @@ ce_page_ip4_new (NMConnection *connection,
 
 	priv->window_group = gtk_window_group_new ();
 
-	s_con = NM_SETTING_CONNECTION (nm_connection_get_setting (connection, NM_TYPE_SETTING_CONNECTION));
+	s_con = nm_connection_get_setting_connection (connection);
 	g_assert (s_con);
 	priv->connection_id = g_strdup (nm_setting_connection_get_id (s_con));
 
-	priv->setting = (NMSettingIP4Config *) nm_connection_get_setting (connection, NM_TYPE_SETTING_IP4_CONFIG);
+	priv->setting = nm_connection_get_setting_ip4_config (connection);
 	if (!priv->setting) {
 		priv->setting = NM_SETTING_IP4_CONFIG (nm_setting_ip4_config_new ());
 		nm_connection_add_setting (connection, NM_SETTING (priv->setting));
