@@ -456,14 +456,14 @@ ce_page_wireless_new (NMConnection *connection,
 	                                      "WirelessPage",
 	                                      _("Wireless")));
 	if (!self) {
-		g_set_error_literal (error, 0, 0, _("Could not load WiFi user interface."));
+		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Could not load WiFi user interface."));
 		return NULL;
 	}
 
 	wireless_private_init (self);
 	priv = CE_PAGE_WIRELESS_GET_PRIVATE (self);
 
-	priv->setting = (NMSettingWireless *) nm_connection_get_setting (connection, NM_TYPE_SETTING_WIRELESS);
+	priv->setting = nm_connection_get_setting_wireless (connection);
 	if (!priv->setting) {
 		priv->setting = NM_SETTING_WIRELESS (nm_setting_wireless_new ());
 		nm_connection_add_setting (connection, NM_SETTING (priv->setting));
